set.seed(23423)

#load package
require(devtools)
require(roxygen2)
require(msir)
require(RColorBrewer)

#Available from Zenodo via 10.5281/zenodo.3686248
require("EDMhelper")


#load data
dat<-read.csv("Virtanen_2020_JEcology_Data.csv")
nm<-names(dat)

#summed shoot biomass
dat$mean_shoot<-rowMeans(dat[,nm[grep(".cm", nm)][-grep("a.cm", nm[grep(".cm", nm)])]], na.rm=T)
dat$Psummer<-dat$PJuly+dat$PJune


#get segments (all observations are in one single segment)
dat$sindex<-paste(dat$site, dat$block, dat$genet, dat$ramet)
max(table(dat$sindex, dat$year))
dat<-dat[order(dat$sindex, dat$year),]

sgm<-segment_data(dat$sindex)

#make standardized data
dnames<-c("mean_shoot", "herbiv")
dnames2<-c("GDD5MJJ", "Psummer")
df<-normalize_data(dat[,c(dnames, dnames2)])$xnorm

#Plot time series
yrdat<-unique(dat[,c("year", "GDD5MJJ", "Psummer")])
require(lme4)
ag1<-with(dat, aggregate(cbind(mean_shoot=mean_shoot, herbiv=herbiv), list(year=year, treat=treatm6, site=site, block=block, genet=genet), function(x) mean(x,na.rm=T)))
ag2<-with(ag1, aggregate(cbind(mean_shoot=mean_shoot, herbiv=herbiv), list(year=year, treat=treat), function(x) cbind(mean(x,na.rm=T), sd(x, na.rm=T))))
trtlst<-sort(unique(ag2$treat))
collst<-adjustcolor(brewer.pal(n = 7, name = "Dark2")[c(1:5,7)], alpha.f = 0.5)

pdf("figures/summarydat_200820.pdf", width=12, height=8, colormodel = "cmyk", useDingbats = FALSE)
  par(mfrow=c(2,1), mar=c(4,4,2,2))
  plot(yrdat$year, yrdat$GDD5MJJ, type="b", xlab="Year", ylab="Climate (GDDMJJ)")
  plot(yrdat$year, yrdat$Psummer, type="b", xlab="Year", ylab="Summer Precip.")
  
  par(mfrow=c(1,1), mar=c(4,4,2,2))
  plot(jitter(ag1$year,0.8), ag1$herbiv, col=collst[as.factor(ag1$treat)], pch=16, cex=0.5, xlab="Year", ylab="Herbivory Index")
  for(i in 1:length(trtlst)) {
    ps<-which(ag2$treat==trtlst[i])
    lines(ag2$year[ps], ag2$herbiv[,1][ps], col=collst[i], lwd=2)
  }
  legend("topright", legend = as.character(trtlst), fill = collst, ncol=3, bty="n")
  
  plot(jitter(ag1$year,0.8), log10(ag1$mean_shoot+1), col=collst[as.factor(ag1$treat)], pch=16, cex=0.5, xlab="Year", ylab="log10(Shoot Length+1)")
  for(i in 1:length(trtlst)) {
    ps<-which(ag2$treat==trtlst[i])
    lines(ag2$year[ps], log10(ag2$mean_shoot[,1][ps]+1), col=collst[i], lwd=2)
  }
  legend("topright", legend = as.character(trtlst), fill = collst, ncol=3, bty="n")
dev.off()




#run simplex on all columns
maxE_test<-4

#get best E
simplex_out <- lapply(dnames, function(dnames){
  simplex(df[,c(dnames)], E=2:maxE_test, lib=sgm, pred=sgm, tau=1, silent = TRUE)
})

climdat<-unique(cbind(dat$year, df[,c(dnames2)]))
simplex_out2 <- lapply(dnames2, function(dnames2){
  simplex(climdat[,c(dnames2)], E=2:maxE_test, tau=1, silent = TRUE)
})


simplex_out[[length(simplex_out)+1]]<-simplex_out2[[1]]
simplex_out[[length(simplex_out)+1]]<-simplex_out2[[2]]

names(simplex_out)<-c(dnames, dnames2)

plot_simplex(simplex_out)
best_E<-find_max_E(simplex_out, buffer=1, predtype = "rho")
names(best_E)<-c(dnames, dnames2)

#run CCM
sgm_trt<-dat$treatm6[sgm[,1]]

sgm_N<-sgm[sgm_trt=="N",]
sgm_J<-sgm[sgm_trt=="J",]
sgm_P<-sgm[sgm_trt=="P",]
sgm_PJ<-sgm[sgm_trt=="PJ",]
sgm_RP<-sgm[sgm_trt=="RP",]
sgm_RPJ<-sgm[sgm_trt=="RPJ",]

sglst<-list(sgm_N, sgm_J, sgm_P,
            sgm_PJ, sgm_RP, sgm_RPJ, sgm)
names(sglst)<-c("N", "J", "P", "PJ", "RP", "RPJ", "all")

summaryout<-list()
sigout<-list()
plotout<-list()

#pre-specify combinations to test
vars_matrix_ord<-data.frame(lib_column=c(rep(dnames, each=3)),
                            target_column=c(dnames[2], dnames2, dnames[1], dnames2),
                            best_E=c(rep(best_E[1:length(dnames)],each=3)))
vars_matrix_ord<-vars_matrix_ord[c(1:3),]

#run time-delay CCM

if(FALSE) {
  num_samples<-1000
  pst<-length(sglst)
  maxl<-length(unique(unlist(apply(sglst[[pst]], 1, function(x) {x[1]:x[2]}))))
  ccm_del_out<-ccm_delay_easy(df=df, best_E = best_E, lib_segments=sglst[[pst]],
                            pred_segments=sglst[[pst]], tp = -1:0, num_samples=num_samples,
                            lib_sizes=c(5, 10, seq(0, 1000, by=50)[-1]), vars_matrix_ord=vars_matrix_ord)
  
  #summarize results
  summaryout_del<-ccm_summary(ccm_output = ccm_del_out, predtype = "rho")
  
  #run significance tests
  sigout_del<-significance_test(ccm_output = ccm_del_out, predtype = "rho")
  
  sigout_tp<-find_tp(sigout_del, cutoff = 0.05)
  
  #plot prediction skill at the maximum library size as a function of tp
  plotout_del<-ccm_delay_plot(summaryout_del)
  
  save(list=c("maxl", "ccm_del_out", "summaryout_del", "sigout_del", "sigout_tp", "plotout_del"), file = "data/ccm_saved_200820.rda", version = 2)
} else {
  load("data/ccm_saved_200820.rda")
}


#plot outputs
summaryout_del_plot<-summaryout_del
direction_list<-data.frame(oldname=sort(unique(summaryout_del_plot$direction)), newname=NA)
direction_list$newname<-c("Temperature causes Growth", "Herbivory causes Growth", "Precipitation causes Growth")
summaryout_del_plot$direction<-direction_list$newname[match(summaryout_del_plot$direction, direction_list$oldname)]



#p-values
liblst<-sort(unique(summaryout_del_plot$lib_size))
mod1<-lm(log(Q50.)~log(lib_size)*as.factor(tp), data=summaryout_del[summaryout_del$direction=="GDD5MJJ causes mean_shoot",])
mod2<-lm(log(Q50.)~log(lib_size)*as.factor(tp), data=summaryout_del[summaryout_del$direction=="herbiv causes mean_shoot",])
mod3<-lm(log(Q50.)~log(lib_size)*as.factor(tp), data=summaryout_del[summaryout_del$direction=="Psummer causes mean_shoot",])


require(coda)
samp_size<-c(c0=effectiveSize(summaryout_del_plot$Q50.[summaryout_del_plot$direction=="Temperature causes Growth" & summaryout_del_plot$tp==0]),
             c1=effectiveSize(summaryout_del_plot$Q50.[summaryout_del_plot$direction=="Temperature causes Growth" & summaryout_del_plot$tp==-1]),
             h0=effectiveSize(summaryout_del_plot$Q50.[summaryout_del_plot$direction=="Herbivory causes Growth" & summaryout_del_plot$tp==0]),
             h1=effectiveSize(summaryout_del_plot$Q50.[summaryout_del_plot$direction=="Herbivory causes Growth" & summaryout_del_plot$tp==-1]),
             p0=effectiveSize(summaryout_del_plot$Q50.[summaryout_del_plot$direction=="Precipitation causes Growth" & summaryout_del_plot$tp==0]),
             p1=effectiveSize(summaryout_del_plot$Q50.[summaryout_del_plot$direction=="Precipitation causes Growth" & summaryout_del_plot$tp==-1]))

pv<-c(c0=(1-mean(mean(ccm_del_out$rho[ccm_del_out$target_column=="GDD5MJJ" & ccm_del_out$tp==0 & ccm_del_out$lib_size==min(liblst)])<ccm_del_out$rho[ccm_del_out$target_column=="GDD5MJJ" & ccm_del_out$tp==0 & ccm_del_out$lib_size==max(liblst)])),
      c1=(1-mean(mean(ccm_del_out$rho[ccm_del_out$target_column=="GDD5MJJ" & ccm_del_out$tp==-1 & ccm_del_out$lib_size==min(liblst)])<ccm_del_out$rho[ccm_del_out$target_column=="GDD5MJJ" & ccm_del_out$tp==-1 & ccm_del_out$lib_size==max(liblst)])),
      h0=(1-mean(mean(ccm_del_out$rho[ccm_del_out$target_column=="herbiv" & ccm_del_out$tp==0 & ccm_del_out$lib_size==min(liblst)])<ccm_del_out$rho[ccm_del_out$target_column=="herbiv" & ccm_del_out$tp==0 & ccm_del_out$lib_size==max(liblst)])),
      h1=(1-mean(mean(ccm_del_out$rho[ccm_del_out$target_column=="herbiv" & ccm_del_out$tp==-1 & ccm_del_out$lib_size==min(liblst)])<ccm_del_out$rho[ccm_del_out$target_column=="herbiv" & ccm_del_out$tp==-1 & ccm_del_out$lib_size==max(liblst)])),
      p0=(1-mean(mean(ccm_del_out$rho[ccm_del_out$target_column=="Psummer" & ccm_del_out$tp==0 & ccm_del_out$lib_size==min(liblst)])<ccm_del_out$rho[ccm_del_out$target_column=="Psummer" & ccm_del_out$tp==0 & ccm_del_out$lib_size==max(liblst)])),
      p1=(1-mean(mean(ccm_del_out$rho[ccm_del_out$target_column=="Psummer" & ccm_del_out$tp==-1 & ccm_del_out$lib_size==min(liblst)])<ccm_del_out$rho[ccm_del_out$target_column=="Psummer" & ccm_del_out$tp==-1 & ccm_del_out$lib_size==max(liblst)])),
      c0c1=round(pt(summary(mod1)$coefficients["as.factor(tp)0", 3], mean(samp_size[1:2])),3),
      h0h1=round(pt(summary(mod2)$coefficients["as.factor(tp)0", 3], mean(samp_size[3:4])),3),
      p0p1=round(pt(summary(mod3)$coefficients["as.factor(tp)0", 3], mean(samp_size[5:6])),3))

pdf("figures/ccm_lagplot_200820.pdf", width=4, height=9, colormodel = "cmyk", useDingbats = FALSE)
  par(mfrow=c(3,1), mar=c(2,4.5,2,2), oma=c(2,0,0,0))
  matplot(liblst,
          cbind(summaryout_del_plot$Q50.[summaryout_del_plot$direction=="Temperature causes Growth" & summaryout_del_plot$tp==0],
                summaryout_del_plot$Q50.[summaryout_del_plot$direction=="Temperature causes Growth" & summaryout_del_plot$tp==-1]),
          type="l", col=c("blue", "red"), lty=1:2,
          xlab="Library Length", ylab=expression(paste("Predictive Skill (", rho, ")")), ylim=c(0, 0.14), lwd=2)
  abline(h=0, lty=3)
  polygon(c(liblst, rev(liblst)), c(summaryout_del_plot$Q15.86553.[summaryout_del_plot$direction=="Temperature causes Growth" & summaryout_del_plot$tp==0],
                                    rev(summaryout_del_plot$Q84.13447.[summaryout_del_plot$direction=="Temperature causes Growth" & summaryout_del_plot$tp==0])),
          border=NA, col=adjustcolor("blue", alpha.f = 0.2))
  polygon(c(liblst, rev(liblst)), c(summaryout_del_plot$Q15.86553.[summaryout_del_plot$direction=="Temperature causes Growth" & summaryout_del_plot$tp==-1],
                                    rev(summaryout_del_plot$Q84.13447.[summaryout_del_plot$direction=="Temperature causes Growth" & summaryout_del_plot$tp==-1])),
          border=NA, col=adjustcolor("red", alpha.f = 0.2))
  legend(400, 0.055, c(paste("lag(0): p <", pv[1]+1e-3),
                      paste("lag(-1): p <", pv[2]+1e-3)),
         col =c("blue", "red"), lty=1:2, lwd=2, bty="n")
  text(600, 0.01, paste("lag(0) vs. lag(-1): p =", pv[7]))
  
  
  matplot(liblst,
          cbind(summaryout_del_plot$Q50.[summaryout_del_plot$direction=="Herbivory causes Growth" & summaryout_del_plot$tp==0],
                summaryout_del_plot$Q50.[summaryout_del_plot$direction=="Herbivory causes Growth" & summaryout_del_plot$tp==-1]),
          type="l", col=c("blue", "red"), lty=1:2,
          xlab="Library Length", ylab=expression(paste("Predictive Skill (", rho, ")")), ylim=c(0, 0.14),lwd=2)
  abline(h=0, lty=3)
  polygon(c(liblst, rev(liblst)), c(summaryout_del_plot$Q15.86553.[summaryout_del_plot$direction=="Herbivory causes Growth" & summaryout_del_plot$tp==0],
                                    rev(summaryout_del_plot$Q84.13447.[summaryout_del_plot$direction=="Herbivory causes Growth" & summaryout_del_plot$tp==0])),
          border=NA, col=adjustcolor("blue", alpha.f = 0.2))
  polygon(c(liblst, rev(liblst)), c(summaryout_del_plot$Q15.86553.[summaryout_del_plot$direction=="Herbivory causes Growth" & summaryout_del_plot$tp==-1],
                                    rev(summaryout_del_plot$Q84.13447.[summaryout_del_plot$direction=="Herbivory causes Growth" & summaryout_del_plot$tp==-1])),
          border=NA, col=adjustcolor("red", alpha.f = 0.2))
  legend(400, 0.055, c(paste("lag(0): p <", pv[3]+1e-3),
                      paste("lag(-1): p <", pv[4]+1e-3)),
         col =c("blue", "red"), lty=1:2, lwd=2, bty="n")
  text(600, 0.01, paste("lag(0) vs. lag(-1): p =", pv[8]))
  
  
  matplot(liblst,
          cbind(summaryout_del_plot$Q50.[summaryout_del_plot$direction=="Precipitation causes Growth" & summaryout_del_plot$tp==0],
                summaryout_del_plot$Q50.[summaryout_del_plot$direction=="Precipitation causes Growth" & summaryout_del_plot$tp==-1]),
          type="l", col=c("blue", "red"), lty=1:2,
          xlab="Library Length", ylab=expression(paste("Predictive Skill (", rho, ")")), ylim=c(0, 0.14),lwd=2)
  abline(h=0, lty=3)
  polygon(c(liblst, rev(liblst)), c(summaryout_del_plot$Q15.86553.[summaryout_del_plot$direction=="Precipitation causes Growth" & summaryout_del_plot$tp==0],
                                    rev(summaryout_del_plot$Q84.13447.[summaryout_del_plot$direction=="Precipitation causes Growth" & summaryout_del_plot$tp==0])),
          border=NA, col=adjustcolor("blue", alpha.f = 0.2))
  polygon(c(liblst, rev(liblst)), c(summaryout_del_plot$Q15.86553.[summaryout_del_plot$direction=="Precipitation causes Growth" & summaryout_del_plot$tp==-1],
                                    rev(summaryout_del_plot$Q84.13447.[summaryout_del_plot$direction=="Precipitation causes Growth" & summaryout_del_plot$tp==-1])),
          border=NA, col=adjustcolor("red", alpha.f = 0.2))
  legend(400, 0.055, c(paste("lag(0): p <", pv[3]+1e-3),
                       paste("lag(-1): p <", pv[4]+1e-3)),
         col =c("blue", "red"), lty=1:2, lwd=2, bty="n")
  text(600, 0.01, paste("lag(0) vs. lag(-1): p =", pv[9]))
  
  mtext("Library Length", 1, outer=TRUE, line=0.5, adj = 0.6)
dev.off()

#run s-mapping
smap_out <- lapply(dnames, function(dnames){
  s_map(df[,c(dnames)], E=best_E[dnames], lib=sgm, pred=sgm, tau=1, silent = TRUE)
})
names(smap_out)<-dnames

smap_out2 <- lapply(dnames2, function(dnames2){
  s_map(df[,c(dnames2)], E=best_E[dnames2], lib=sgm, pred=sgm, tau=1, silent = TRUE)
})
names(smap_out2)<-dnames2


smap_out[[length(smap_out)+1]]<-smap_out2[[1]]
smap_out[[length(smap_out)+1]]<-smap_out2[[2]]
names(smap_out)<-c(dnames, dnames2)



#find best theta for all time series
best_theta<-find_max_theta(smap_out, buffer=1, predtype = "rho")
names(best_theta)<-c(dnames, dnames2)
plot_smap(smap_out)

#calculate s-map coefficients - focus on mean_shoot
best_theta["mean_shoot"]
best_E["mean_shoot"]
#probably 1 year delay on climate, 0 year delay on herbiv.
df_mod<-apply(df, 2, function(x) x+abs(pmin(0, min(x,na.rm=T))))
blockdat<-make_block(block = df_mod[,"mean_shoot"], max_lag = best_E["mean_shoot"]+1, lib = sgm)
bk_herbv<-make_block(block = df_mod[,"herbiv"], max_lag = 1, lib = sgm)
bk_gdd<-make_block(block = df_mod[,"GDD5MJJ"], max_lag = 3, lib = sgm)
bk_precip<-make_block(block = df_mod[,"Psummer"], max_lag = 1, lib = sgm)


#append blocks
blockdat[,4]<-bk_gdd[,3]
blockdat[,5]<-bk_herbv[,2]
blockdat[,6]<-bk_precip[,2]
colnames(blockdat)<-c("time", "shoot", "shoot_1", "gdd_1", "herbiv", "precip")


#run test
smap_out1<-block_lnlp(block = blockdat, lib = sgm, pred = sgm, method = "s-map", tp = 0, columns = c(2:5), target_column = 1, first_column_time = TRUE, stats_only = FALSE, theta = unlist(best_theta["mean_shoot"]), silent = TRUE, save_smap_coefficients = TRUE)

smap_out_noprecip<-block_lnlp(block = blockdat[,1:5], lib = sgm, pred = sgm, method = "s-map", tp = 0, columns = c(2:4), target_column = 1, first_column_time = TRUE, stats_only = FALSE, theta = unlist(best_theta["mean_shoot"]), silent = TRUE, save_smap_coefficients = TRUE)

smap_out1$rho^2
smap_out_noprecip$rho^2

smap_out1$rmse
smap_out_noprecip$rmse

abs(smap_out1$rmse-smap_out_noprecip$rmse)/smap_out1$rmse
1-smap_out1$rmse/smap_out_noprecip$rmse

#plot coefficients
pf<-function(x, y, col=NULL, ...) {
  if(is.null(col)) {
    col<-1
  }
  
  points(x, y, col=adjustcolor(col, alpha.f = 0.3), ...)
  abline(h=0, v=0, lty=3, col=1);
  
  ps<-is.finite(x) & is.finite(y)
  x<-x[ps]; y<-y[ps]
  
  #mod<-loess(y~x, nsigma = 1, enp.target = 2)
  #xplt<-seq(min(x, na.rm=T), max(x, na.rm=T), length=20)
  #predf<-predict(mod, newdata=data.frame(x=xplt), se = TRUE)
  
  #n<-cut(x, 20)
  #tn<-table(n)
  #tn<-predf$df
  #pred<-predf$fit
  #upper<-predf$fit+predf$se.fit*sqrt(pmax(1, sqrt(tn)))
  #lower<-predf$fit-predf$se.fit*sqrt(pmax(1, sqrt(tn)))
  
  mod<-loess.sd(y~x, nsigma = 1, span=abs(diff(range(x,na.rm=T)))*5)
  
  xplt<-sort(mod$x)
  pred<-mod$y[order(mod$x)]
  upper<-mod$upper[order(mod$x)]
  lower<-mod$lower[order(mod$x)]
  
  matlines(xplt, cbind(pred, upper, lower), col=col, lty=c(1,2,2), lwd=1.5)
}

#full
cfout1<-smap_out1$smap_coefficients[[1]]
colnames(cfout1)<-c("shoot_1", "gdd_1", "herbiv", "precip", "int")



pdf("figures/growth_eff_pooled_200820.pdf", width=8, height=4, colormodel = "cmyk", useDingbats = FALSE)
  par(mfrow=c(2,3), mar=c(4,4,2,2), oma=c(1,1,0,0))
  plot(herbiv~gdd_1, cfout1, type="n",
       xlab="",
       ylab="");
  pf(x = cfout1$gdd_1, y = cfout1$herbiv, pch=16, cex=0.5)
  abline(v=0, lty=3)
  title("a.", adj=0.05, outer=FALSE, line = -1)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Temp."))), 1, line=3)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Herbivory"))), 2, line=2.8)
  
  xtmp<-((blockdat[,"gdd_1"]-abs(min((dat$GDD5MJJ-mean(dat$GDD5MJJ,na.rm=T))/sd(dat$GDD5MJJ,na.rm=T),na.rm=T)))*
           sd(dat$GDD5MJJ,na.rm=T))+mean(dat$GDD5MJJ,na.rm=T)
  plot(gdd_1~xtmp, cfout1, type="n",
       xlab="",
       ylab="");
  pf(xtmp, cfout1$gdd_1, pch=16, cex=0.5)
  title("b.", adj=0.05, outer=FALSE, line = -1)
  mtext(expression(paste(italic("Temp."), "(", italic("t"), "-1)")), 1, line=3)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Temp."))), 2, line=2.8)
  
  
  plot(herbiv~xtmp, cfout1, type="n",
       xlab="",
       ylab="");
  pf(xtmp, cfout1$herbiv, pch=16, cex=0.5)
  title("c.", adj=0.05, outer=FALSE, line = -1)
  mtext(expression(paste(italic("Temp."), "(", italic("t"), "-1)")), 1, line=3)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Herbivory"))), 2, line=2.8)
  
  
  
  
  
  plot(herbiv~precip, cfout1, type="n",
       xlab="",
       ylab="");
  pf(x = cfout1$precip, y = cfout1$herbiv, pch=16, cex=0.5)
  abline(v=0, lty=3)
  title("d.", adj=0.05, outer=FALSE, line = -1)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Preip."))), 1, line=3)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Herbivory"))), 2, line=2.8)
  
  xtmp2<-((blockdat[,"precip"]-abs(min((dat$Psummer-mean(dat$Psummer,na.rm=T))/sd(dat$Psummer,na.rm=T),na.rm=T)))*
           sd(dat$Psummer,na.rm=T))+mean(dat$Psummer,na.rm=T)
  plot(precip~xtmp2, cfout1, type="n",
       xlab="",
       ylab="");
  pf(xtmp2, cfout1$precip, pch=16, cex=0.5)
  title("e.", adj=0.05, outer=FALSE, line = -1)
  mtext(expression(paste(italic("Preip."), "(", italic("t"), ")")), 1, line=3)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Preip."))), 2, line=2.8)
  
  
  plot(herbiv~xtmp2, cfout1, type="n",
       xlab="",
       ylab="");
  pf(xtmp2, cfout1$herbiv, pch=16, cex=0.5)
  title("f.", adj=0.05, outer=FALSE, line = -1)
  mtext(expression(paste(italic("Precip."), "(", italic("t"), ")")), 1, line=3)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Herbivory"))), 2, line=2.8)
  
dev.off()





#run test by treatment
#run test
smap_out<-list()
cfout<-list()
ps<-list()

for(pst in 1:length(sglst)) {
  smap_out[[pst]]<-block_lnlp(block = blockdat, lib = sglst[[pst]], pred = sglst[[pst]], method = "s-map", tp = 0, columns = c(2:5), target_column = 1, first_column_time = TRUE, stats_only = FALSE, theta = unlist(best_theta["mean_shoot"]), silent = TRUE, save_smap_coefficients = TRUE)
  #smap_out$rho^2
  ps[[pst]]<-sort(unique(unlist(apply(sglst[[pst]], 1, function(x) {x[1]:x[2]}))))
  
  #plot coefficients
  cfout[[pst]]<-smap_out[[pst]]$smap_coefficients[[1]]
  colnames(cfout[[pst]])<-c("shoot_1", "gdd_1", "herbiv", "precip", "int")
}

collst<-brewer.pal(n = 7, name = "Dark2")[c(1:5,7)]

pdf("figures/growth_partial_eff_bytrt_200820.pdf", width=6, height=8, colormodel = "cmyk", useDingbats = FALSE)
  par(mfrow=c(2,1), mar=c(4,4,2,2))
  
  plot(c(-0.26, 0.15), c(-0.28, -0.0), type="n",
       xlab="",
       ylab="")
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Temp."))), 1, line=3)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Herbivory"))), 2, line=2.8)
  
  for(pst in 1:(length(sglst)-1)) {
    pf(cfout[[pst]]$gdd_1, cfout[[pst]]$herbiv, col=collst[pst], pch=16, cex=0.5)
  }
  abline(v=0, lty=3)
  legend("topright", legend = names(sglst)[c(1,3,5,2,4,6)], fill=collst[c(1,3,5,2,4,6)], ncol=2, bty="n")


  plot(c(-0.26, 0.15), c(-0.28, -0.0), type="n",
       xlab="",
       ylab="")
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Precip."))), 1, line=3)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Herbivory"))), 2, line=2.8)
  
  for(pst in 1:(length(sglst)-1)) {
    pf(cfout[[pst]]$precip, cfout[[pst]]$herbiv, col=collst[pst], pch=16, cex=0.5)
  }
  abline(v=0, lty=3)
  
  
  
dev.off()


pdf("figures/growth_climate_eff_bytrt_200820.pdf", width=8, height=6, colormodel = "cmyk", useDingbats = FALSE)
  par(mfrow=c(2,3), mar=c(2,2,2,2), oma=c(2,2,0,0))
  for(pst in c(1,3,5,2,4,6)) {
    plot(c(190, 450), c(-0.26, 0.15), xlab="gdd_1", ylab="gdd_1 eff.", type="n", main=names(sglst)[pst])
    abline(v=seq(200, 450, by=50), h=seq(-0.25, 0.15, by=0.05), col=adjustcolor("darkgrey",alpha.f = 0.5))
    pf(xtmp[ps[[pst]]], cfout[[pst]]$gdd_1, col=collst[pst], pch=16, cex=0.5)
  }
  mtext(expression(paste(italic("Temp."), "(", italic("t"), "-1)")), 1, outer=T, line=0.8)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Temp."))), 2, outer=T, line=0.1)

  
  par(mfrow=c(2,3), mar=c(2,2,2,2), oma=c(2,2,0,0))
  for(pst in c(1,3,5,2,4,6)) {
    plot(c(45, 220), c(-0.26, 0.15), xlab="precip", ylab="precip eff.", type="n", main=names(sglst)[pst])
    abline(v=seq(0, 250, by=50), h=seq(-0.25, 0.15, by=0.05), col=adjustcolor("darkgrey",alpha.f = 0.5))
    pf(xtmp2[ps[[pst]]], cfout[[pst]]$precip, col=collst[pst], pch=16, cex=0.5)
  }
  mtext(expression(paste(italic("Precip."), "(", italic("t"), ")")), 1, outer=T, line=0.8)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Precip."))), 2, outer=T, line=0.1)
  
  
dev.off()
  
pdf("figures/growth_herbiv_eff_bytrt_200820.pdf", width=8, height=6, colormodel = "cmyk", useDingbats = FALSE)
  par(mfrow=c(2,3), mar=c(2,2,2,2), oma=c(2,2,0,0))
  for(pst in c(1,3,5,2,4,6)) {
    plot(c(190, 450), c(-0.28, -0.0), xlab="gdd_1", ylab="herbiv eff.", type="n", main=names(sglst)[pst])
    abline(v=seq(200, 450, by=50), h=seq(-0.3, 0.15, by=0.05), col=adjustcolor("darkgrey",alpha.f = 0.5))
    pf((xtmp[ps[[pst]]]), cfout[[pst]]$herbiv, col=collst[pst], pch=16, cex=0.5)
  }
  mtext(expression(paste(italic("Temp."), "(", italic("t"), "-1)")), 1, outer=T, line=0.8)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Herbivory"))), 2, outer=T, line=0.1)

  par(mfrow=c(2,3), mar=c(2,2,2,2), oma=c(2,2,0,0))
  for(pst in c(1,3,5,2,4,6)) {
    plot(c(45, 220), c(-0.28, -0.0), xlab="precip", ylab="herbiv eff.", type="n", main=names(sglst)[pst])
    abline(v=seq(0, 250, by=50), h=seq(-0.3, 0.15, by=0.05), col=adjustcolor("darkgrey",alpha.f = 0.5))
    pf((xtmp2[ps[[pst]]]), cfout[[pst]]$herbiv, col=collst[pst], pch=16, cex=0.5)
  }
  mtext(expression(paste(italic("Precip."), "(", italic("t"), ")")), 1, outer=T, line=0.8)
  mtext(expression(paste(partialdiff, italic("Shoot"), "/", partialdiff, italic("Herbivory"))), 2, outer=T, line=0.1)
dev.off()
